@@ -1,7 +1,9 @@
 package Media::Info;
 
-our $DATE = '2019-07-03'; # DATE
-our $VERSION = '0.130'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-06-02'; # DATE
+our $DIST = 'Media-Info'; # DIST
+our $VERSION = '0.131'; # VERSION
 
 use 5.010001;
 use strict;
@@ -15,6 +17,17 @@ our @EXPORT_OK = qw(
 
 our %SPEC;
 
+sub _type_from_name {
+    require Filename::Audio;
+    require Filename::Video;
+    require Filename::Image;
+    my $name = shift;
+
+    Filename::Video::check_video_filename(filename => $name) ? "video" :
+    Filename::Audio::check_audio_filename(filename => $name) ? "audio" :
+    Filename::Image::check_image_filename(filename => $name) ? "image" : "unknown";
+}
+
 $SPEC{get_media_info} = {
     v => 1.1,
     summary => 'Return information on media file/URL',
@@ -26,6 +39,13 @@ $SPEC{get_media_info} = {
 Note that not every backend can retrieve URL. At the time of this writing, only
 the Mplayer backend can.
 
+Many fields will depend on the backend used. Common fields returned include:
+
+* `backend`: the `Media::Info::*` backend module used, e.g. `Ffmpeg`.
+* `type_from_name`: either `image`, `audio`, `video`, or `unknown`. This
+  is determined from filename (extension).
+
+
 _
             schema  => 'str*',
             pos     => 0,
@@ -72,7 +92,25 @@ sub get_media_info {
         my $func = \&{"$mod\::get_media_info"};
         my $res = $func->(media => $args{media});
         if ($res->[0] == 200) {
+            # add some common fields
+
+            # backend
             $res->[3]{'func.backend'} = $backend;
+            $res->[2]{backend} = $backend;
+            $res->[2]{type_from_name} = _type_from_name($_);
+
+            # video_longest_side, video_shortest_side, video_orientation (if not set by backend)
+            if ($res->[2]{video_height} && $res->[2]{video_width}) {
+                if ($res->[2]{video_height} > $res->[2]{video_width}) {
+                    $res->[2]{video_longest_side}  = $res->[2]{video_height};
+                    $res->[2]{video_shortest_side} = $res->[2]{video_width};
+                    $res->[2]{video_orientation} = 'portrait' unless $res->[2]{video_orientation};
+                } else {
+                    $res->[2]{video_longest_side}  = $res->[2]{video_width};
+                    $res->[2]{video_shortest_side} = $res->[2]{video_height};
+                    $res->[2]{video_orientation} = 'landscape' unless $res->[2]{video_orientation};
+                }
+            }
         }
         return $res unless $res->[0] == 412;
     }
@@ -99,7 +137,7 @@ Media::Info - Return information on media file/URL
 
 =head1 VERSION
 
-This document describes version 0.130 of Media::Info (from Perl distribution Media-Info), released on 2019-07-03.
+This document describes version 0.131 of Media::Info (from Perl distribution Media-Info), released on 2020-06-02.
 
 =head1 SYNOPSIS
 
@@ -140,7 +178,7 @@ Usage:
 
  get_media_info(%args) -> [status, msg, payload, meta]
 
-Return information on media file/URL.
+Return information on media fileE<sol>URL.
 
 This function is not exported by default, but exportable.
 
@@ -154,11 +192,23 @@ Choose specific backend.
 
 =item * B<media>* => I<str>
 
-Media file/URL.
+Media fileE<sol>URL.
 
 Note that not every backend can retrieve URL. At the time of this writing, only
 the Mplayer backend can.
 
+Many fields will depend on the backend used. Common fields returned include:
+
+=over
+
+=item * C<backend>: the C<Media::Info::*> backend module used, e.g. C<Ffmpeg>.
+
+=item * C<type_from_name>: either C<image>, C<audio>, C<video>, or C<unknown>. This
+is determined from filename (extension).
+
+=back
+
+
 =back
 
 Returns an enveloped result (an array).
@@ -190,7 +240,7 @@ feature.
 
 =head1 SEE ALSO
 
-L<Video::Info> - This module is first written because I couldn't install
+L<Video::Info> - C<Media::Info> is first written because I couldn't install
 Video::Info. That module doesn't seem maintained (last release is in 2003 at the
 time of this writing), plus I want a per-backend namespace organization instead
 of per-format one, and a simple functional interface instead of OO interface.
@@ -201,7 +251,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
